#!/usr/bin/env node
import * as path from 'path';
import { createFile } from './util/createFile.js';
import { downloadConfig } from './util/downloadConfig.js';
import { isFolderExist } from './util/isFolderExist.js';
import { readPackageVersion } from './util/readVersionPackage.js';

const dotenv = require('dotenv');
dotenv.config();
const init = async (args) => {
    const [argRootCatalog, argTemplate] = args;
    const version = await readPackageVersion('./package.json');
    const rootCatalog = argRootCatalog ? argRootCatalog : './snp';
    const template = argTemplate ? argTemplate : 'node';
    return { rootCatalog, template, sUpdaterVersion: version };
};
const createConfigFile = async (config) => {
    const { rootCatalog, template, sUpdaterVersion } = config;
    const filePath = `${rootCatalog}/snp.config.json`;
    await isFolderExist({
        folderPath: rootCatalog,
        createFolder: true,
    });
    await createFile({
        filePath,
        content: JSON.stringify({ sUpdaterVersion, template }),
    });
    return { rootCatalog, template, sUpdaterVersion };
};
const downloadRemoteConfig = async (config) => {
    const fileMap = await downloadConfig(config.template, config.rootCatalog);
    const organizeFileMap = (fileMap) => {
        const files = {};
        fileMap.forEach((file) => {
            const fileName = file.substring(0, file.lastIndexOf('-'));
            if (!files[fileName]) {
                files[fileName] = [];
            }
            files[fileName].push(file);
        });
        return { fileMap, files };
    };
    return Object.assign(Object.assign({}, config), { fileMap: organizeFileMap(fileMap) });
};
const buildConfig = async (config) => {
    console.log(config);
    //END WORK HERE
};
let args = process.argv.slice(2);
if (Boolean(process.env.SDEBUG)) {
    args = [path.join('./.snp'), 'node'];
}
init(args)
    .then((config) => createConfigFile(config))
    .then((config) => downloadRemoteConfig(config))
    .then((config) => buildConfig(config));
// fileMap: {
//   fileMap: [ 'README.md-default.md', 'README.md-instructions.md', 'ab.js-default.md' ],
//       files: { 'README.md': [ 'README.md-default.md', 'README.md-instructions.md' ],  'ab.js': [ 'ab.js-default.md'] }
// }

export { buildConfig, createConfigFile, downloadRemoteConfig, init };
