import 'fs';
import { basename, dirname, join } from 'path';
import { isFileExists } from './isFileExists.js';
import { isFolderExist } from './isFolderExist.js';
import { toCreateFile } from './toCreateFile.js';

async function createFile({ filePath, fileName, folderPath, content, options = { createFolder: true, overwriteFile: true, backupFile: true }, }) {
    if (!filePath && (!folderPath || !fileName)) {
        throw new Error("Either 'filePath' or both 'folderPath' and 'fileName' are required.");
    }
    fileName = filePath ? basename(filePath) : fileName;
    folderPath = filePath ? dirname(filePath) : folderPath;
    if (!filePath) {
        filePath = join(folderPath, fileName);
    }
    try {
        await isFolderExist({
            folderPath,
            createFolder: (options === null || options === void 0 ? void 0 : options.createFolder) || true,
        });
        if (await isFileExists(filePath)) {
            console.warn('File already exists: ' + filePath);
        }
        await toCreateFile({ filePath, content, options });
        return filePath;
    }
    catch (error) {
        console.error(error);
        return '';
    }
}

export { createFile };
