/// <reference types="node" />
/**
 * Creates a new file in the file system.
 *
 * @param {string} filePath - The path to the file to be created.
 * @param {string | Buffer} content - The content to be written to the file.
 * @param {Object} [options] - Additional options for file creation.
 * @param {boolean} [options.overwriteFile=true] - If true, overwrite the file if it already exists.
 * @param {boolean} [options.backupFile=true] - If true, creates a backup of the existing file before overwriting (if applicable).
 * @returns {Promise<void>} - Returns a Promise that resolves when the file is successfully created.
 *                            Rejects with an error if the file creation fails.
 */
interface ToCreateFileParams {
    filePath: string;
    content: string | Buffer;
    options?: {
        overwriteFile?: boolean;
        backupFile?: boolean;
    };
}
export declare function toCreateFile({ filePath, content, options, }: ToCreateFileParams): Promise<void>;
export {};
